sievetools.ResidueClass
=======================

.. abjad-lineage:: abjad.tools.sievetools.ResidueClass.ResidueClass.ResidueClass

.. autoclass:: abjad.tools.sievetools.ResidueClass.ResidueClass.ResidueClass
   :noindex:

Read-only Properties
--------------------

.. autoattribute:: abjad.tools.sievetools.ResidueClass.ResidueClass.ResidueClass.modulo
   :noindex:

.. autoattribute:: abjad.tools.sievetools.ResidueClass.ResidueClass.ResidueClass.residue
   :noindex:

.. autoattribute:: abjad.tools.sievetools.ResidueClass.ResidueClass.ResidueClass.storage_format
   :noindex:

Methods
-------

.. automethod:: abjad.tools.sievetools.ResidueClass.ResidueClass.ResidueClass.get_boolean_train
   :noindex:

.. automethod:: abjad.tools.sievetools.ResidueClass.ResidueClass.ResidueClass.get_congruent_bases
   :noindex:

Special Methods
---------------

.. automethod:: abjad.tools.sievetools.ResidueClass.ResidueClass.ResidueClass.__and__
   :noindex:

.. automethod:: abjad.tools.sievetools.ResidueClass.ResidueClass.ResidueClass.__eq__
   :noindex:

.. automethod:: abjad.tools.sievetools.ResidueClass.ResidueClass.ResidueClass.__ge__
   :noindex:

.. automethod:: abjad.tools.sievetools.ResidueClass.ResidueClass.ResidueClass.__gt__
   :noindex:

.. automethod:: abjad.tools.sievetools.ResidueClass.ResidueClass.ResidueClass.__le__
   :noindex:

.. automethod:: abjad.tools.sievetools.ResidueClass.ResidueClass.ResidueClass.__lt__
   :noindex:

.. automethod:: abjad.tools.sievetools.ResidueClass.ResidueClass.ResidueClass.__ne__
   :noindex:

.. automethod:: abjad.tools.sievetools.ResidueClass.ResidueClass.ResidueClass.__or__
   :noindex:

.. automethod:: abjad.tools.sievetools.ResidueClass.ResidueClass.ResidueClass.__repr__
   :noindex:

.. automethod:: abjad.tools.sievetools.ResidueClass.ResidueClass.ResidueClass.__xor__
   :noindex:
